@@ -6,6 +6,7 @@ import pandas as pd
 from SharedData.Logger import Logger
 from SharedData.SharedDataFeeder import SharedDataFeeder
 from SharedData.Metadata import Metadata
+from SharedData.SharedDataRealTime import SharedDataRealTime
 
 class SharedData:
     
@@ -69,4 +70,6 @@ class SharedData:
 
     def getSymbols(self, collection):        
         return self.getMetadata(collection).static.index.values
-  
\ No newline at end of file
+  
+    def SubscribeRealTime(self):
+        SharedDataRealTime.Subscribe(self)
\ No newline at end of file
