@@ -11,8 +11,11 @@ from pathlib import Path
 from multiprocessing import shared_memory
 from datetime import datetime, timedelta
 
+
 from SharedData.Logger import Logger
 from SharedData.SharedDataAWSS3 import S3SyncDownloadDataFrame,S3Upload
+from SharedData.SharedDataRealTime import SharedDataRealTime
+
 
 class SharedDataFrame:
 
@@ -214,3 +217,10 @@ class SharedDataFrame:
         Logger.log.debug('Writing %s/%s/%s/%s ...%.2f%% %.2f sec!' % \
             (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))
         
+    def Broadcast(self,idx,col):
+        SharedDataRealTime.Broadcast(
+            self.sharedData,
+            self.feeder,
+            self.period,
+            self.tag,
+            idx,col)
\ No newline at end of file
