@@ -1,4 +1,5 @@
-import os,boto3,time
+
+import os,boto3,time,subprocess,sys
 import pandas as pd
 import numpy as np
 
@@ -32,7 +33,7 @@ class SharedDataRealTime:
                 'feeder' : feeder,
                 'period' : period,
                 'tag' : tag,
-                'idx' : idx,
+                'idx' : idx.astype('int64').tolist(),
                 'col' : col,
                 'data' : data.tolist()
             }            
@@ -65,17 +66,29 @@ class SharedDataRealTime:
         return SharedDataRealTime.producer[shdata.database]
     
     def Subscribe(shdata):
-        today = pd.Timestamp(pd.Timestamp.now().date)
-        if not shdata['RT']['D1'].exists(today):            
+        today = pd.Timestamp(pd.Timestamp.now().date())
+        if not shdata['RT']['D1'].exists(today):
             df = pd.DataFrame(
                 0,
                 index = ['MarketData','Signals','Porfolios'],
-                columns = ['watchdog']            
+                columns = ['watchdog']
             )
-            tms = time.mktime(pd.Timestamp.now().timetuple())
-            df.loc[shdata.database,'watchdog'] = tms
+            df.loc[shdata.database,'watchdog'] = time.time() - 61
             shdata['RT']['D1'][today] = df
             shdata['RT']['D1'].tags[today].Write()
-            
-            
+        
+        # start subprocess if 
+        df = shdata['RT']['D1'][today]
+        if time.time() - df.loc[shdata.database,'watchdog'] > 15:
+            proc = subprocess.Popen(['python','-m',\
+                'SharedData.SharedDataRealTimeProcess'],
+                stdout=subprocess.PIPE, stderr=subprocess.PIPE,\
+                universal_newlines=True, shell=True)
+            rc = proc.poll()
+            return (rc is None)
+        
+        #success
+        return True
 
+        # C:\Users\TRADEBOT04\src\SharedData\venv\Scripts\python.exe
+        # C:\Users\TRADEBOT04\src\SharedData\venv\Lib\site-packages\SharedData\SharedDataRealTimeProcess.py
\ No newline at end of file
